; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;===========================================================================
;-| AI Setup |--------------------------------------------------------------

[Command]
name = "ai1"
command = x,x,x,x,x,x,x,x,x,x,a+b+c+x+y+z
time = 1

[Command]
name = "ai2"
command = y,y,y,y,y,y,y,y,y,y,a+b+c+x+y+z
time = 1

[Command]
name = "ai3"
command = z,z,z,z,z,z,z,z,z,z,z,z,a+b+c+x+y+z
time = 1

[Command]
name = "ai4"
command = a,a,a,a,a,a,a,a,a,a,a+b+c+x+y+z
time = 1

[Command]
name = "ai5"
command = b,b,b,b,b,b,b,b,b,b,a+b+c+x+y+z
time = 1

[Command]
name = "ai6"
command = c,c,c,c,c,c,c,c,c,c,a+b+c+x+y+z
time = 1

[Command]
name = "ai7"
command = F,F,F,F,F,F,F,F,a+b+c+x+y+z
time = 1

[Command]
name = "ai8"
command = B,B,B,B,B,B,B,B,B,a+b+c+x+y+z
time = 1

[Command]
name = "ai9"
command = U,U,U,U,U,U,U,U,U,a+b+c+x+y+z
time = 1

[Command]
name = "ai10"
command = D,D,D,D,D,D,D,D,D,a+b+c+x+y+z
time = 1

[Command]
name = "ai11"
command = F,F,F,B,B,B,U,U,U,a+b+c+x+y+z
time = 1

[Command]
name = "ai12"
command = F,B,F,B,F,B,F,B,F,a+b+c+x+y+z
time = 1

;-| Aternate State Motions |-----------------------------------------------

;-| Super Attack Motions |-------------------------------------------------

[Command]
name = "Home_Run_Smash_-_QP"
command = ~D, DB, B, D, DB, B, x
time = 30

[Command]
name = "Home_Run_Smash_-_HP"
command = ~D, DB, B, D, DB, B, y
time = 30

[Command]
name = "Seismic_Stomp"
command = ~D, DF, F, D, DF, F, b
time = 30

;-| EX Attack Motions |----------------------------------------------------

[Command]
name = "Barrel_Roll_Swing_-_EX"
command = ~D, DB, B, x+y
time = 30

[Command]
name = "Power_Wave_-_EX"
command = ~D, DF, F, x+y
time = 30

;-| Special Attack Motions |-----------------------------------------------

[Command]
name = "Barrel_Roll_Swing_-_QP"
command = ~D, DB, B, x
time = 30

[Command]
name = "Barrel_Roll_Swing_-_HP"
command = ~D, DB, B, y
time = 30

[Command]
name = "Power_Wave_-_QP"
command = ~D, DF, F, x
time = 30

[Command]
name = "Power_Wave_-_HP"
command = ~D, DF, F, y
time = 30

;-| Special Technique Motions |--------------------------------------------
[Command]
name = "Super_Jump"     ;Required (do not remove)
command = D, U
time = 10

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]


;===========================================================================
;---------------------------------------------------------------------------
; AI
;---------------------------------------------------------------------------
; AI Setup

[State -1, AI] 
type = VarSet ;Variable Set
trigger1 = command = "ai1"
trigger2 = command = "ai2"
trigger3 = command = "ai3"
trigger4 = command = "ai4"
trigger5 = command = "ai5"
trigger6 = command = "ai6"
trigger7 = command = "ai7"
trigger8 = command = "ai8"
trigger9 = command = "ai9"
trigger10 = command = "ai10"
trigger11 = command = "ai11"
trigger12 = command = "ai12"
var(59) = 1 ;Sets Variable 59 to 1 (Activates AI)

;---------------------------------------------------------------------------
; Home Run Smash (Level 1)

[State -1, Home Run Smash (Level 1)]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = P2bodydist X <= 80 ;opponent must be 80 pixels away from Roy or closer
trigger1 = P2bodydist X >= 40 ;opponent must be 40 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 50]; 5 percent chance of using attack
trigger2 = ctrl = 1 ;AI must be in control of Roy
trigger2 = statetype = S ;Roy must be standing on the ground
trigger2 = power >= 1000 ;1000 energy points (one stock) are required
trigger2 = P2bodydist X <= 80 ;opponent must be 80 pixels away from Roy or closer
trigger2 = P2bodydist X >= 40 ;opponent must be 40 pixels away from Roy or further
trigger2 = P2bodydist Y >= -340 ;opponent must be 340 pixels above Roy or lower
trigger2 = P2bodydist Y <= -320 ;opponent be 320 pixels above Roy or higher
trigger2 = P2StateType = A ;opponent must be in the air
trigger2 = random = [0, 900]; 90 percent chance of using attack
value = 3100 ;switches to State 3100 (Home Run Smash (Level 1))

;---------------------------------------------------------------------------
; Home Run Smash (Level 2)

[State -1, Home Run Smash (Level 2)]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = power >= 2000 ;2000 energy points (two stocks) are required
trigger1 = P2bodydist X <= 80 ;opponent must be 80 pixels away from Roy or closer
trigger1 = P2bodydist X >= 60 ;opponent must be 60 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 500]; 50 percent chance of using attack
value = 3200 ;switches to State 3200 (Home Run Smash (Level 2))

;---------------------------------------------------------------------------
; Seismic Stomp

[State -1, Seismic Stomp]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = power >= 3000 ;3000 energy points (three stocks) are required
trigger1 = P2bodydist X <= 80 ;opponent must be 80 pixels away from Roy or closer
trigger1 = P2bodydist X >= 20 ;opponent must be 20 pixels away from Roy or further
trigger1 = P2bodydist Y >= -200 ;opponent must be 200 pixels above Roy or lower
trigger1 = random = [0, 900]; 90 percent chance of using attack
value = 3300 ;switches to State 3300 (Seismic Stomp)

;---------------------------------------------------------------------------
; Barrel Roll Swing - QP

[State -1, Barrel Roll Swing - QP]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X <= 120 ;opponent must be 120 pixels away from Roy or closer
trigger1 = P2bodydist X >= 80 ;opponent must be 80 pixels away from Roy or further
trigger1 = P2bodydist Y >= -100 ;opponent must be 100 pixels above Roy or lower
trigger1 = random = [0, 200]; 20 percent chance of using attack
value = 1100 ;switches to State 1100 (Barrel Roll Swing - QP)

;---------------------------------------------------------------------------
; Barrel Roll Swing - HP

[State -1, Barrel Roll Swing - HP]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X <= 200 ;opponent must be 200 pixels away from Roy or closer
trigger1 = P2bodydist X >= 150 ;opponent must be 150 pixels away from Roy or further
trigger1 = P2bodydist Y >= -100 ;opponent must be 100 pixels above Roy or lower
trigger1 = random = [0, 200]; 20 percent chance of using attack
value = 1200 ;switches to State 1200 (Barrel Roll Swing - HP)

;---------------------------------------------------------------------------
; Barrel Roll Swing - EX

[State -1, Barrel Roll Swing - EX]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = power >= 500 ;500 energy points (half stock) are required
trigger1 = P2bodydist X <= 200 ;opponent must be 200 pixels away from Roy or closer
trigger1 = P2bodydist X >= 80 ;opponent must be 80 pixels away from Roy or further
trigger1 = P2bodydist Y >= -100 ;opponent must be 100 pixels above Roy or lower
trigger1 = random = [0, 300]; 30 percent chance of using attack
value = 1300 ;switches to State 1300 (Barrel Roll Swing - EX)

;---------------------------------------------------------------------------
; Power Wave - QP

[State -1, Power Wave - QP]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X >= 40 ;opponent must be 40 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be airborne
trigger1 = random = [0, 100]; 10 percent chance of using attack
value = 1400 ;switches to State 1400 (Power Wave - QP)

;---------------------------------------------------------------------------
; Power Wave - HP

[State -1, Power Wave - HP]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X >= 80 ;opponent must be 80 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be airborne
trigger1 = random = [0, 100]; 10 percent chance of using attack
value = 1500 ;switches to State 1500 (Power Wave - HP)

;---------------------------------------------------------------------------
; Power Wave - EX

[State -1, Power Wave - EX]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = power >= 500 ;500 energy points (half stock) are required
trigger1 = P2bodydist X >= 40 ;opponent must be 40 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be airborne
trigger1 = random = [0, 100]; 10 percent chance of using attack
value = 1600 ;switches to State 1600 (Power Wave - EX)

;---------------------------------------------------------------------------
; Quick jab

[State -1, Quick jab]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X <= 40 ;opponent must be 40 pixels away from Roy or closer
trigger1 = P2bodydist X >= 30 ;opponent must be 30 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 600]; 60 percent chance of using attack
trigger2 = stateno = 220 ;Roy must be in State 220 (Standing quick poke)
trigger2 = AnimElemNo(0) = 3 ;Roy must be in the third frame of the animation
trigger2 = random = [0, 900]; 90 percent chance of using attack
value = 200 ;switches to State 200 (Quick jab)

;---------------------------------------------------------------------------
; Medium back swing

[State -1, Medium back swing]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X <= 70 ;opponent must be 70 pixels away from Roy or closer
trigger1 = P2bodydist X >= 50 ;opponent must be 50 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 300]; 30 percent chance of using attack
trigger2 = stateno = 200 ;Roy must be in State 200 (Quick jab)
trigger2 = AnimElemNo(0) = 3 ;Roy must be in the third frame of the animation
trigger2 = random = [0, 900]; 90 percent chance of using attack
value = 210 ;switches to State 210 (Medium back swing)

;---------------------------------------------------------------------------
; Standing quick poke

[State -1, Standing quick poke]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X <= 25 ;opponent must be 25 pixels away from Roy or closer
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 900]; 90 percent chance of using attack
value = 220 ;switches to State 220 (Standing quick poke)

;---------------------------------------------------------------------------
; Hard downward swing

[State -1, Hard downward swing]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X <= 90 ;opponent must be 90 pixels away from Roy or closer
trigger1 = P2bodydist X >= 60 ;opponent must be 60 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 300]; 30 percent chance of using attack
value = 230 ;switches to State 230 (Hard downward swing)


;---------------------------------------------------------------------------
; Crouching quick swing

[State -1, Crouching quick swing]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = C ;Roy must be crouching
trigger1 = P2bodydist X <= 60 ;opponent must be 60 pixels away from Roy or closer
trigger1 = P2bodydist X >= 40 ;opponent must be 40 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 600]; 60 percent chance of using attack
value = 400 ;switches to State 400 (Crouching quick swing)

;---------------------------------------------------------------------------
; Crouching medium swing

[State -1, Crouching medium swing]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = C ;Roy must be crouching
trigger1 = P2bodydist X <= 90 ;opponent must be 90 pixels away from Roy or closer
trigger1 = P2bodydist X >= 60 ;opponent must be 60 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 600]; 60 percent chance of using attack
value = 410 ;switches to State 410 (Crouching medium swing)

;---------------------------------------------------------------------------
; Crouching stick twirl

[State -1, Crouching stick twirl]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = C ;Roy must be crouching
trigger1 = P2bodydist X <= 60 ;opponent must be 60 pixels away from Roy or closer
trigger1 = P2bodydist X >= 40 ;opponent must be 40 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 600]; 60 percent chance of using attack
value = 420 ;switches to State 420 (Crouching stick twirl)

;---------------------------------------------------------------------------
; Power slide

[State -1, Power slide]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = C ;Roy must be crouching
trigger1 = P2bodydist X <= 140 ;opponent must be 140 pixels away from Roy or closer
trigger1 = P2bodydist X >= 60 ;opponent must be 60 pixels away from Roy or further
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 900]; 90 percent chance of using attack
value = 430 ;switches to State 430 (Power slide)

;---------------------------------------------------------------------------
; HP grab attack

[State -1, HP grab attack]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X <= 20 ;opponent must be 20 pixels away from Roy or closer
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 500]; 50 percent chance of using attack
value = 800 ;switches to State 800 (HP grab attack - Attempt)

;---------------------------------------------------------------------------
; Aerial quick poke

[State -1, Aerial quick poke]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = P2bodydist X <= 50 ;opponent be 50 pixels away from Roy or closer
trigger1 = P2bodydist X >= 40 ;opponent be 40 pixels away from Roy or further
trigger1 = P2bodydist Y >= 5 ;opponent be 5 pixels below Roy or lower
trigger1 = P2bodydist Y <= 10 ;opponent be 10 pixels below Roy or higher
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 600]; 60 percent chance of using attack
trigger2 = ctrl = 1 ;AI must be in control of Roy
trigger2 = StateType = A ;Roy must be airborne
trigger2 = P2bodydist X <= 50 ;opponent must be 50 pixels away from Roy or closer
trigger2 = P2bodydist X >= 40 ;opponent must be 40 pixels away from Roy or further
trigger2 = P2bodydist Y >= -5 ;opponent must be 5 pixels above Roy or lower
trigger2 = P2bodydist Y <= -10 ;opponent be 10 pixels above Roy or higher
trigger2 = P2StateType = A ;opponent must be in the air
trigger2 = random = [0, 900]; 90 percent chance of using attack
trigger3 = stateno = 620 ;Roy must be in State 620 (Aerial quick kick)
trigger3 = AnimElemNo(0) = 2 ;Roy must be in the second frame of the animation
trigger3 = random = [0, 900]; 90 percent chance of using attack
value = 600 ;switches to State 600 (Aerial quick poke)

;---------------------------------------------------------------------------
; Aerial hard backswing

[State -1, Aerial hard backswing]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = StateType = A ;Roy must be airborne
trigger1 = P2bodydist X <= 80 ;opponent be 80 pixels away from Roy or closer
trigger1 = P2bodydist X >= 50 ;opponent be 50 pixels away from Roy or further
trigger1 = P2bodydist Y >= 10 ;opponent be 10 pixels below Roy or lower
trigger1 = P2bodydist Y <= 15 ;opponent be 15 pixels below Roy or higher
trigger1 = P2StateType != A ;opponent must not be in the air
trigger1 = random = [0, 600]; 60 percent chance of using attack
trigger2 = ctrl = 1 ;AI must be in control of Roy
trigger2 = StateType = A ;Roy must be airborne
trigger2 = Pos Y <= -250 ;must be at least 250 pixels above the ground
trigger2 = P2bodydist X <= 80 ;opponent must be 80 pixels away from Roy or closer
trigger2 = P2bodydist X >= 50 ;opponent must be 50 pixels away from Roy or further
trigger2 = P2bodydist Y >= -25 ;opponent must be 25 pixels above Roy or lower
trigger2 = P2bodydist Y <= -10 ;opponent be 10 pixels above Roy or higher
trigger2 = P2StateType = A ;opponent must be in the air
trigger2 = random = [0, 900]; 90 percent chance of using attack
trigger3 = stateno = 600 ;Roy must be in State 600 (Aerial quick poke)
trigger3 = AnimElemNo(0) = 5 ;Roy must be in the fifth frame of the animation
trigger3 = random = [0, 900]; 90 percent chance of using attack
value = 610 ;switches to State 610 (Aerial hard backswing)

;---------------------------------------------------------------------------
; Aerial quick kick

[State -1, Aerial quick kick]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = StateType = A ;Roy must be airborne
trigger1 = P2bodydist X <= 25 ;opponent must be 25 pixels away from Roy or closer
trigger1 = P2bodydist Y >= 10 ;opponent be 10 pixels below Roy or lower
trigger1 = random = [0, 600]; 60 percent chance of using attack
value = 620 ;switches to State 620 (Aerial quick kick);

;---------------------------------------------------------------------------
; Standing launcher

[State -1, Standing launcher]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = stateno = 400 ;Roy must be in state 400 (Crouching quick swing)
trigger1 = AnimElemNo(0) = 4 ;move must be completed on fourth frame
trigger1 = random = [0, 900]; 90 percent chance of using attack
value = 310 ;switches to State 310 (Standing launcher)

;---------------------------------------------------------------------------
; Crouch

[State -1, Crouch]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = random = [0, 500]; 50 percent chance of using move
value = 11 ;switches to State 11 (Crouch)

;---------------------------------------------------------------------------
; Power charge

[State -1, Power charge]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = P2bodydist X >= 200 ;opponent must be 200 pixels away from Roy or further
trigger1 = random = [0, 800]; 80 percent chance of using move
value = 160 ;switches to State 160 (Power charge)

;---------------------------------------------------------------------------
; Super Jump

[State -1, Super Jump]

type = changestate
triggerall = var(59) != 0 ;AI must be active
triggerall = RoundState = 2 ;players are currently in battle
trigger1 = ctrl = 1 ;AI must be in control of Roy
trigger1 = statetype = S ;Roy must be standing on the ground
trigger1 = Pos Y = 0 ;kicks in if Roy is on the ground
trigger1 = P2bodydist Y <= -250 ;opponent be 250 pixels above Roy or higher
trigger1 = random = [0, 900]; 90 percent chance of using move
value = 411 ;switches to State 411 (Super Jump)

;===========================================================================
;Alternate States

;===========================================================================
;Super Attacks

;---------------------------------------------------------------------------
; Home Run Smash (Level 1)

[State -1, Home Run Smash - QP]
type = ChangeState
value = 3100
triggerall = command = "Home_Run_Smash_-_QP"
triggerall = statetype = S
triggerall = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = ctrl = 1 ;player must be in control of Roy
trigger2 = stateno = 310 ;Roy must be in state 310 (Standing launcher)
trigger2 = AnimElemNo(0) = [3, 5]
;^move must be between the third and fifth frames^

;---------------------------------------------------------------------------
; Home Run Smash (Level 2)

[State -1, Home Run Smash - HP]
type = ChangeState
value = 3200
triggerall = command = "Home_Run_Smash_-_HP"
triggerall = statetype = S
triggerall = power >= 2000 ;2000 energy points (two stocks) are required
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Seismic Stomp

[State -1, Seismic Stomp]
type = ChangeState
value = 3300
triggerall = command = "Seismic_Stomp"
triggerall = statetype = S
triggerall = power >= 3000 ;3000 energy points (three stocks) are required
trigger1 = ctrl = 1 ;player must be in control of Roy

;===========================================================================
;EX Attacks

;---------------------------------------------------------------------------
; Barrel Roll Swing - EX

[State -1, Barrel Roll Swing - EX]
type = ChangeState
value = 1300
triggerall = command = "Barrel_Roll_Swing_-_EX"
triggerall = statetype = S
triggerall = power >= 500 ;500 energy points (half stock) are required
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Power Wave - EX

[State -1, Power Wave - EX]
type = ChangeState
value = 1600
triggerall = command = "Power_Wave_-_EX"
triggerall = statetype = S
triggerall = power >= 500 ;500 energy points (half stock) are required
trigger1 = ctrl = 1 ;player must be in control of Roy

;===========================================================================
;Special Attacks

;---------------------------------------------------------------------------
; Barrel Roll Swing - QP

[State -1, Barrel Roll Swing - QP]
type = ChangeState
value = 1100
triggerall = command = "Barrel_Roll_Swing_-_QP"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Barrel Roll Swing - HP

[State -1, Barrel Roll Swing - HP]
type = ChangeState
value = 1200
triggerall = command = "Barrel_Roll_Swing_-_HP"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Power Wave - QP

[State -1, Power Wave - QP]
type = ChangeState
value = 1400
triggerall = command = "Power_Wave_-_QP"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Power Wave - HP

[State -1, Power Wave - HP]
type = ChangeState
value = 1500
triggerall = command = "Power_Wave_-_HP"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;===========================================================================
;Special Techniques

;---------------------------------------------------------------------------
; Hop Forward

[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Hop Backward

[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Super Jump

[State -1, Super Jump]
type = ChangeState
value = 411
triggerall = command = "Super_Jump"
trigger1 = statetype = S
trigger1 = Pos Y = 0 ;kicks in if Roy is on the ground
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Power Charge

[State -1, Power Charge]
type = ChangeState
value = 160
triggerall = command = "hold_c"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy
trigger1 = power < 3000 ;Roy must have less than 3000 points of energy

;---------------------------------------------------------------------------
;; Dodge

;[State -1, Dodge]
;type = ChangeState
;value = 501
;triggerall = command = "z"
;trigger1 = statetype = S
;trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Parry High

;[State -1, Parry High]
;type = HitOverride
;triggerall = command = "fwd"
;triggerall = statetype = S ;can't parry in the air
;trigger1 = stateno != 3100
;trigger1 = ctrl = 1 ;player must be in control of {char. name}
;trigger2 = stateno = 508 ;State 508 (Parry High)
;attr = SA, AA, AP ;standing and aerial, all hit attacks, all projectiles
;stateno = 508 ;switches to State 508 (Parry High)
;time = # ;parry timing window

;---------------------------------------------------------------------------
; Parry Low

;[State -1, Parry Low]
;type = HitOverride
;triggerall = command = "downfwd"
;triggerall = statetype = S ;can't parry in the air
;trigger1 = ctrl = 1 ;player must be in control of {char. name}
;trigger2 = stateno = 509 ;State 509 (Parry Low)
;attr = C, AA, AP ;crouching, all hit attacks, all projectiles
;stateno = 509 ;switches to State 509 (Parry Low)
;time = # ;parry timing window

;---------------------------------------------------------------------------
; Parry Inhibitor

;[State -1, Parry Inhibitor]
;type = HitOverride
;triggerall = ctrl = 0 ;player must not be in control of {char. name}
;trigger1 = stateno = 3100 ;State 3100 (Oteigh Drop - Attempt)
;trigger2 = stateno = 320 ;State 320 (Ura Nage - Attempt)
;attr = SA, AA, AP ;standing and aerial, all hit attacks, all projectiles
;stateno = -1 ;state does not change
;time = 0 ;parry timing window

;---------------------------------------------------------------------------
; Breakout Burst

;[State -1, Breakout Burst]
;type = ChangeState
;value = 511 ;switches to State 511 (Breakout Burst)
;triggerall = command = "Breakout_Burst"
;trigger1 = P2BodyDist X <= 30 ;must be 30 pixels away from opponent or closer
;trigger1 = stateno = 150 ;{char. name} must be in state 150 (Block)

;===========================================================================
;Combo Attacks

;---------------------------------------------------------------------------
; Standing launcher

[State -1, Standing launcher]
type = ChangeState
value = 310
triggerall = command = "y"
triggerall = statetype = C
trigger1 = stateno = 400 ;Roy must be in state 400 (Crouching quick swing)
trigger1 = AnimElemNo(0) = [4, 5]
;^move must be between the fourth and fifth frames^

;===========================================================================
;Standard Attacks

;---------------------------------------------------------------------------
; HP grab attack

[State -1, HP grab attack]
type = ChangeState
value = 800 ;switches to State 800 (HP grab attack - Attempt)
triggerall = command = "fwd_y"
triggerall = statetype = S ;must be standing on the ground
trigger1 = p2bodydist X < 20 ;must be closer than twenty pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Quick jab

[State -1, Quick jab]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy
trigger2 = stateno = 220 ;Roy must be in state 220 (Standing quick poke)
trigger2 = AnimElemNo(0) = 3 ;move must be completed on third frame

;---------------------------------------------------------------------------
; Medium back swing

[State -1, Medium back swing]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy
trigger2 = stateno = 200 ;Roy must be in state 200 (Quick jab)
trigger2 = AnimElemNo(0) = [2, 3]
;^move must be between the second and third frames^

;---------------------------------------------------------------------------
; Standing quick poke

[State -1, Standing quick poke]
type = ChangeState
value = 220
triggerall = command = "a"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Hard downward swing

[State -1, Hard downward swing]
type = ChangeState
value = 230
triggerall = command = "b"
triggerall = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Crouching quick swing

[State -1, Crouching quick swing]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Crouching medium swing

[State -1, Crouching medium swing]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Crouching stick twirl

[State -1, Crouching stick twirl]
type = ChangeState
value = 420
triggerall = command = "a"
triggerall = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Power slide

[State -1, Short power slide]
type = ChangeState
value = 430
triggerall = command = "b"
triggerall = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Roy

;---------------------------------------------------------------------------
; Aerial quick poke

[State -1, Aerial quick poke]
type = ChangeState
value = 600
triggerall = command = "x"
triggerall = statetype = A
trigger1 = ctrl = 1 ;player must be in control of Roy
trigger2 = stateno = 620 ;Roy must be in state 620 (Aerial quick kick)
trigger2 = AnimElemNo(0) = 2 ;move must be completed on second frame

;---------------------------------------------------------------------------
; Aerial hard backswing

[State -1, Aerial hard backswing]
type = ChangeState
value = 610
triggerall = command = "y"
triggerall = statetype = A
trigger1 = ctrl = 1 ;player must be in control of Roy
trigger2 = stateno = 600 ;Roy must be in state 600 (Aerial quick poke)
trigger2 = AnimElemNo(0) = [2, 5]
;^move must be between the second and fifth frames^

;---------------------------------------------------------------------------
; Aerial quick kick

[State -1, Aerial quick kick]
type = ChangeState
value = 620
triggerall = command = "a"
triggerall = statetype = A
trigger1 = ctrl = 1 ;player must be in control of Roy

